/**
 * Represents a credential used to authenticate to a docker registry.
 *
 * Uses the official Docker Login Github Action to authenticate.
 *
 * @see https://github.com/marketplace/actions/docker-login
 * @stability stable
 */
export declare class DockerCredential {
    readonly name: string;
    readonly registry?: string | undefined;
    readonly usernameKey?: string | undefined;
    readonly passwordKey?: string | undefined;
    /**
     * Reference credential secrets to authenticate to DockerHub.
     *
     * This method assumes
     * that your credentials will be stored as long-lived Github Secrets under the
     * usernameKey and personalAccessTokenKey.
     *
     * The default for usernameKey is `DOCKERHUB_USERNAME`. The default for personalAccessTokenKey
     * is `DOCKERHUB_TOKEN`. If you do not set these values, your credentials should be
     * found in your Github Secrets under these default keys.
     *
     * @stability stable
     */
    static dockerHub(creds?: DockerHubCredentialSecrets): DockerCredential;
    /**
     * Create a credential for ECR.
     *
     * This method will reuse your AWS credentials to log in to AWS.
     * Your AWS credentials are already used to deploy your CDK stacks. It can be supplied via
     * Github Secrets or using an IAM role that trusts the Github OIDC identity provider.
     *
     * TODO: note the necessary permissions for the IAM role here.
     *
     * NOTE - All ECR repositories in the same account and region share a domain name
     * (e.g., 0123456789012.dkr.ecr.eu-west-1.amazonaws.com), and can only have one associated
     * set of credentials (and DockerCredential). Attempting to associate one set of credentials
     * with one ECR repo and another with another ECR repo in the same account and region will
     * result in failures when using these credentials in the pipeline.
     *
     * @stability stable
     */
    static ecr(registry: string): DockerCredential;
    /**
     * Create a credential for a custom registry.
     *
     * This method assumes that you will have long-lived
     * Github Secrets stored under the usernameKey and passwordKey that will authenticate to the
     * registry you provide.
     *
     * @see https://github.com/marketplace/actions/docker-login
     * @stability stable
     */
    static customRegistry(registry: string, creds: ExternalDockerCredentialSecrets): DockerCredential;
    private constructor();
}
/**
 * Locations of Github Secrets used to authenticate to DockerHub.
 *
 * @stability stable
 */
export interface DockerHubCredentialSecrets {
    /**
     * The key of the Github Secret containing the DockerHub username.
     *
     * @default 'DOCKERHUB_USERNAME'
     * @stability stable
     */
    readonly usernameKey?: string;
    /**
     * The key of the Github Secret containing the DockerHub personal access token.
     *
     * @default 'DOCKERHUB_TOKEN'
     * @stability stable
     */
    readonly personalAccessTokenKey?: string;
}
/**
 * Generic structure to supply the locations of Github Secrets used to authenticate to a docker registry.
 *
 * @stability stable
 */
export interface ExternalDockerCredentialSecrets {
    /**
     * The key of the Github Secret containing your registry username.
     *
     * @stability stable
     */
    readonly usernameKey: string;
    /**
     * The key of the Github Secret containing your registry password.
     *
     * @stability stable
     */
    readonly passwordKey: string;
}
